@@ -27,6 +27,9 @@ URL_DICT = {}
 class InvalidUrlError(Exception):
     pass
 
+class ElementAlreadyRegisteredError(Exception):
+    pass
+
 class MetaPage(type):
     def __init__(cls, name, bases, attrs):
         if name not in ('MetaPage', 'Page'):
@@ -147,6 +150,9 @@ class Page(object):
         return self.registered_elements[element_key]
 
     def register_element(self, element_key, element_locator):
+        if self.registered_elements.has_key(element_key) and self.get_registered_element(element_key) != element_locator:
+            error_message = "You are trying to register an element with name '%s' in %s with locator '%s', but it is already registered with a different locator ('%s')." % (element_key, self.__class__, element_locator, self.get_registered_element(element_key))
+            raise ElementAlreadyRegisteredError(error_message)
         self.registered_elements[element_key] = element_locator
 
     def quick_register(self, element_key, element_selector):
